# -*- coding: utf-8 -*-
"""Author information."""


# This information is located in its own file so that it can be loaded
# without importing the main package when its dependencies are not installed.
# See: https://packaging.python.org/guides/single-sourcing-package-version

__author__ = ('Ronald van Haren', 'Jaro Camphuijsen', 'Yifat Dzigan',
              'Niels Drost', 'Fakhereh Alidoost', 'Bouwe Andela',
              'Jerom Aerts', 'Berend Weel', 'Rolf Hut', 'Klaus Zimmermann',
              'Peter Kalverla', 'Barbara Vreede', 'Aytaç Paçal', 'Stef Smeets',
              'Stefan Verhoeven')
__email__ = 'ewatercycle@esciencecenter.nl'
__version__ = '1.2.1'
